==> go.php?file=PhoenixStyle7.002.zip: PhoenixStyleMod_Legion/Boss11.lua <==
﻿psbossfileLegion11=1




function pscmrbossREPORTLegion111(wipe,try,reset,checkforwipe)
if reset==nil then
if checkforwipe==nil or (checkforwipe and pswasonbossLegion11 and pswasonbossLegion11==1) then

	if pswasonbossLegion11==1 then
		pssetcrossbeforereport1=GetTime()

		if psraidoptionson[4][1][1][1]==1 then
			strochkavezcrash=psdidfriendlyf.." |s4id203097|id ("..psmainmtotal.."): "
			reportafterboitwotab(psraidchats3[psraidoptionschat[4][1][1][1]], true, vezaxname, vezaxcrash, 1)
		end
		if psraidoptionson[4][1][1][2]==1 then
			strochkavezcrash=psiccdmgfrom.." |s4id202978|id ("..psmainmtotal.."): "
			reportafterboitwotab(psraidchats3[psraidoptionschat[4][1][1][2]], true, vezaxname2, vezaxcrash2, 1)
		end
		if psraidoptionson[4][1][1][3]==1 then
			strochkavezcrash=psiccdmgfrom.." |s4id203045|id ("..psmainmtotal.."): "
			reportafterboitwotab(psraidchats3[psraidoptionschat[4][1][1][3]], true, vezaxname3, vezaxcrash3, 1)
		end


	end
	if pswasonbossLegion11==1 or (pswasonbossLegion11==2 and try==nil) then

		psiccsavinginf(psbossnames[4][1][1], try, pswasonbossLegion11)

		strochkavezcrash=psdidfriendlyf.." |s4id221028|id ("..psmainmtotal.."): "
		reportafterboitwotab("raid", true, vezaxname, vezaxcrash, nil, nil,0,1)
		strochkavezcrash=psiccdmgfrom.." |s4id202978|id ("..psmainmtotal.."): "
		reportafterboitwotab("raid", true, vezaxname2, vezaxcrash2, nil, nil,0,1)
		strochkavezcrash=psiccdmgfrom.." |s4id203045|id ("..psmainmtotal.."): "
		reportafterboitwotab("raid", true, vezaxname3, vezaxcrash3, nil, nil,0,1)

		psiccrefsvin()

	end




	if wipe then
		pswasonbossLegion11=2
		pscheckbossincombatmcr_legion1=GetTime()+1
	end
end
end
end


function pscmrbossRESETLegion111(wipe,try,reset,checkforwipe)
if reset or wipe==nil then
pswasonbossLegion11=nil


table.wipe(vezaxname)
table.wipe(vezaxcrash)
table.wipe(vezaxname2)
table.wipe(vezaxcrash2)
table.wipe(vezaxname3)
table.wipe(vezaxcrash3)

end
end



function pscombatlogbossLegion11(arg1, arg2, hideCaster, guid1, name1, flag1, new1, guid2, name2, flag2, new2, spellid, spellname, arg11,arg12,arg13,arg14,arg15)




if arg2=="SPELL_DAMAGE" and spellid==203097 and name1 and name2 and name1~=name2 then
  if pswasonbossLegion11==nil then
    pswasonbossLegion11=1
  end
  psunitisplayer(guid2,name2)
  if psunitplayertrue then

    pscheckwipe1()
    if pswipetrue and pswasonbossLegion11~=2 then
      psiccwipereport_legion1("wipe", "try")
    end
    addtotwotables1(name1)
    vezaxsort1()
    local tt2=", "..psdamageceil(arg12)
      if arg13>=0 then
        tt2=", "..psdamageceil(arg12-arg13).." |cffff0000("..psoverkill..": "..psdamageceil(arg13)..")|r"
      end
    pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name1)..name1..psaddcolortxt(2,name1).." > "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2)..tt2, -1, "id1", 1, "|s4id"..spellid.."|id - "..psinfo,psbossnames[4][1][1],2)
  end
end

if arg2=="SPELL_DAMAGE" and spellid==202978 then
  if pswasonbossLegion11==nil then
    pswasonbossLegion11=1
  end
  psunitisplayer(guid2,name2)
  if psunitplayertrue then

    pscheckwipe1()
    if pswipetrue and pswasonbossLegion11~=2 then
      psiccwipereport_legion1("wipe", "try")
    end
    addtotwotables2(name2)
    vezaxsort2()
    local tt2=", "..psdamageceil(arg12)
      if arg13>=0 then
        tt2=", "..psdamageceil(arg12-arg13).." |cffff0000("..psoverkill..": "..psdamageceil(arg13)..")|r"
      end
    pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2)..tt2, -1, "id1", 2, "|s4id"..spellid.."|id - "..psinfo,psbossnames[4][1][1],2)
  end
end


if arg2=="SPELL_PERIODIC_DAMAGE" and spellid==203045 then
  if pswasonbossLegion11==nil then
    pswasonbossLegion11=1
  end
  psunitisplayer(guid2,name2)
  if psunitplayertrue then

    pscheckwipe1()
    if pswipetrue and pswasonbossLegion11~=2 then
      psiccwipereport_legion1("wipe", "try")
    end
    addtotwotables3(name2)
    vezaxsort3()
    local tt2=", "..psdamageceil(arg12)
      if arg13>=0 then
        tt2=", "..psdamageceil(arg12-arg13).." |cffff0000("..psoverkill..": "..psdamageceil(arg13)..")|r"
      end
    pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2)..tt2, -1, "id1", 2, "|s4id"..spellid.."|id - "..psinfo,psbossnames[4][1][1],3)
  end
end



if arg2=="SPELL_CAST_START" and spellid==99999999 then
pscheckrunningbossid(guid1)
pscaststartinfo(spellid,spellname..": %s.", 2, guid1, 91, "|s4id"..spellid.."|id - "..pseventsincomb2,psbossnames[4][1][1])
end



end

==> go.php?file=PhoenixStyle7.302.zip: PhoenixStyleMod_Legion/Boss11.lua <==
﻿psbossfileLegion11=1




function pscmrbossREPORTLegion111(wipe,try,reset,checkforwipe)
if reset==nil then
if checkforwipe==nil or (checkforwipe and pswasonbossLegion11 and pswasonbossLegion11==1) then

	if pswasonbossLegion11==1 then
		pssetcrossbeforereport1=GetTime()

		if psraidoptionson[4][1][1][1]==1 then
			strochkavezcrash=psdidfriendlyf.." |s4id203097|id ("..psmainmtotal.."): "
			reportafterboitwotab(psraidchats3[psraidoptionschat[4][1][1][1]], true, vezaxname, vezaxcrash, 1)
		end
		if psraidoptionson[4][1][1][2]==1 then
			strochkavezcrash=psiccdmgfrom.." |s4id202978|id ("..psmainmtotal.."): "
			reportafterboitwotab(psraidchats3[psraidoptionschat[4][1][1][2]], true, vezaxname2, vezaxcrash2, 1)
		end
		if psraidoptionson[4][1][1][3]==1 then
			strochkavezcrash=psiccdmgfrom.." |s4id203045|id ("..psmainmtotal.."): "
			reportafterboitwotab(psraidchats3[psraidoptionschat[4][1][1][3]], true, vezaxname3, vezaxcrash3, 1)
		end
		if psraidoptionson[4][1][1][4]==1 then
			strochkavezcrash=psmainmgot.." |s4id205043|id ("..psmainmtotal.."): "
			reportafterboitwotab(psraidchats3[psraidoptionschat[4][1][1][4]], true, vezaxname4, vezaxcrash4, 1)
		end


	end
	if pswasonbossLegion11==1 or (pswasonbossLegion11==2 and try==nil) then

		psiccsavinginf(psbossnames[4][1][1], try, pswasonbossLegion11)

		strochkavezcrash=psdidfriendlyf.." |s4id221028|id ("..psmainmtotal.."): "
		reportafterboitwotab("raid", true, vezaxname, vezaxcrash, nil, nil,0,1)
		strochkavezcrash=psiccdmgfrom.." |s4id202978|id ("..psmainmtotal.."): "
		reportafterboitwotab("raid", true, vezaxname2, vezaxcrash2, nil, nil,0,1)
		strochkavezcrash=psiccdmgfrom.." |s4id203045|id ("..psmainmtotal.."): "
		reportafterboitwotab("raid", true, vezaxname3, vezaxcrash3, nil, nil,0,1)
		strochkavezcrash=psmainmgot.." |s4id205043|id ("..psmainmtotal.."): "
		reportafterboitwotab("raid", true, vezaxname4, vezaxcrash4, nil, nil,0,1)

		psiccrefsvin()

	end




	if wipe then
		pswasonbossLegion11=2
		pscheckbossincombatmcr_legion1=GetTime()+1
	end
end
end
end


function pscmrbossRESETLegion111(wipe,try,reset,checkforwipe)
if reset or wipe==nil then
pswasonbossLegion11=nil


table.wipe(vezaxname)
table.wipe(vezaxcrash)
table.wipe(vezaxname2)
table.wipe(vezaxcrash2)
table.wipe(vezaxname3)
table.wipe(vezaxcrash3)
table.wipe(vezaxname4)
table.wipe(vezaxcrash4)

end
end



function pscombatlogbossLegion11(arg1, arg2, hideCaster, guid1, name1, flag1, new1, guid2, name2, flag2, new2, spellid, spellname, arg11,arg12,arg13,arg14,arg15)




if arg2=="SPELL_DAMAGE" and spellid==203097 and name1 and name2 and name1~=name2 then
  if pswasonbossLegion11==nil then
    pswasonbossLegion11=1
  end
  psunitisplayer(guid2,name2)
  if psunitplayertrue then

    pscheckwipe1()
    if pswipetrue and pswasonbossLegion11~=2 then
      psiccwipereport_legion1("wipe", "try")
    end
    addtotwotables1(name1)
    vezaxsort1()
    local tt2=", "..psdamageceil(arg12)
      if arg13>=0 then
        tt2=", "..psdamageceil(arg12-arg13).." |cffff0000("..psoverkill..": "..psdamageceil(arg13)..")|r"
      end
    pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name1)..name1..psaddcolortxt(2,name1).." > "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2)..tt2, -1, "id1", 1, "|s4id"..spellid.."|id - "..psinfo,psbossnames[4][1][1],2)
  end
end

if arg2=="SPELL_DAMAGE" and spellid==202978 then
  if pswasonbossLegion11==nil then
    pswasonbossLegion11=1
  end
  psunitisplayer(guid2,name2)
  if psunitplayertrue then

    pscheckwipe1()
    if pswipetrue and pswasonbossLegion11~=2 then
      psiccwipereport_legion1("wipe", "try")
    end
    addtotwotables2(name2)
    vezaxsort2()
    local tt2=", "..psdamageceil(arg12)
      if arg13>=0 then
        tt2=", "..psdamageceil(arg12-arg13).." |cffff0000("..psoverkill..": "..psdamageceil(arg13)..")|r"
      end
    pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2)..tt2, -1, "id1", 2, "|s4id"..spellid.."|id - "..psinfo,psbossnames[4][1][1],2)
  end
end


if arg2=="SPELL_PERIODIC_DAMAGE" and spellid==203045 then
  if pswasonbossLegion11==nil then
    pswasonbossLegion11=1
  end
  psunitisplayer(guid2,name2)
  if psunitplayertrue then

    pscheckwipe1()
    if pswipetrue and pswasonbossLegion11~=2 then
      psiccwipereport_legion1("wipe", "try")
    end
    addtotwotables3(name2)
    vezaxsort3()
    local tt2=", "..psdamageceil(arg12)
      if arg13>=0 then
        tt2=", "..psdamageceil(arg12-arg13).." |cffff0000("..psoverkill..": "..psdamageceil(arg13)..")|r"
      end
    pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2)..tt2, -1, "id1", 3, "|s4id"..spellid.."|id - "..psinfo,psbossnames[4][1][1],2)
  end
end


if arg2=="SPELL_AURA_APPLIED" and (spellid==205043 or spellid==225943) then
  if pswasonbossLegion11==nil then
    pswasonbossLegion11=1
  end
  psunitisplayer(guid2,name2)
  if psunitplayertrue then

    pscheckwipe1()
    if pswipetrue and pswasonbossLegion11~=2 then
      psiccwipereport_legion1("wipe", "try")
    end
    addtotwotables4(name2)
    vezaxsort4()
    pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 4, "|s4id"..spellid.."|id - "..psinfo,psbossnames[4][1][1],2)
  end
end



if arg2=="SPELL_CAST_START" and spellid==99999999 then
pscheckrunningbossid(guid1)
pscaststartinfo(spellid,spellname..": %s.", 2, guid1, 91, "|s4id"..spellid.."|id - "..pseventsincomb2,psbossnames[4][1][1])
end



end
